summaryrefslogtreecommitdiffstats
path: root/kate/xmlcheck/plugin_katexmlcheck.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kate/xmlcheck/plugin_katexmlcheck.cpp')
-rw-r--r--kate/xmlcheck/plugin_katexmlcheck.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kate/xmlcheck/plugin_katexmlcheck.cpp b/kate/xmlcheck/plugin_katexmlcheck.cpp
index 76d674a..49f2af2 100644
--- a/kate/xmlcheck/plugin_katexmlcheck.cpp
+++ b/kate/xmlcheck/plugin_katexmlcheck.cpp
@@ -99,10 +99,10 @@ PluginKateXMLCheckView::PluginKateXMLCheckView(TQWidget *parent,Kate::MainWindow
{
m_tmp_file=0;
m_proc=0;
- (void) new KAction ( i18n("Validate XML"), 0, TQT_TQOBJECT(this),
+ (void) new TDEAction ( i18n("Validate XML"), 0, TQT_TQOBJECT(this),
TQT_SLOT( slotValidate() ), actionCollection(), "xml_check" );
// TODO?:
//(void) new KAction ( i18n("Indent XML"), 0, this,
// TQT_SLOT( slotIndent() ), actionCollection(), "xml_indent" );
setInstance(new TDEInstance("kate"));
@@ -99,10 +99,10 @@ PluginKateXMLCheckView::PluginKateXMLCheckView(TQWidget *parent,Kate::MainWindow
TQT_SLOT( slotValidate() ), actionCollection(), "xml_check" );
// TODO?:
- //(void) new KAction ( i18n("Indent XML"), 0, this,
+ //(void) new TDEAction ( i18n("Indent XML"), 0, this,
// TQT_SLOT( slotIndent() ), actionCollection(), "xml_indent" );
setInstance(new TDEInstance("kate"));